from dataclasses import dataclass, field
from typing import Literal

from ...._client_utilities import ClientTargetable
from ..api_object import TelegramBotsObject
from .passport_element_error import PassportElementError



@dataclass(init=True, repr=True, slots=True)
class PassportElementErrorFile(PassportElementError):
    # --- description here ---
    """Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.
    
    More info at: https://core.telegram.org/bots/api/#passportelementerrorfile
    """

    # --- properties here ---
    source: str = field(metadata={"ac_type": [str], "ac_name": "source"})
    """Error source, must be *file*
    """

    type: Literal["utility_bill","bank_statement","rental_agreement","passport_registration","temporary_registration"] = field(metadata={"ac_type": [str], "ac_name": "type"})
    """The section of the user's Telegram Passport which has the issue, one of “utility\\_bill”, “bank\\_statement”, “rental\\_agreement”, “passport\\_registration”, “temporary\\_registration”
    """

    file_hash: str = field(metadata={"ac_type": [str], "ac_name": "file_hash"})
    """Base64-encoded file hash
    """

    message: str = field(metadata={"ac_type": [str], "ac_name": "message"})
    """Error message
    """

